=================
Development Notes
=================

Testing
=======

To get the requirements::

    % pip install mock

To run the tests::

    % python setup.py test


Documentation
=============

Documentation is located in ``docs/`` and requires `Sphinx
<http://sphinx-doc.org/>`_ to build.

To get the requirements::

    % pip install Sphinx

To build the docs::

    % cd docs/
    % make html

Documentation committed and pushed to the main repository is available
on ReadTheDocs at `<http://pyelasticsearch.readthedocs.org/>`_.
